@@ -23,7 +23,7 @@ Functions:
 """
 import pickle
 from RSSparser.date_time import  date_object
-from RSSparser.datetime import datetime
+from datetime import datetime
 from RSSparser.print_news import print_json_format, print_regular_format
 import logging
 import os
